Running TARDIS — TARDIS v0.9.dev692

# Running TARDIS

To run TARDIS requires two files. The atomic database (for more info refer to Atomic Data) and a configuration file (more info at Configuration File).

## Simple Example

After installing TARDIS just download the example directory https://www.dropbox.com/s/svvyr5i7m8ouzdt/tardis_example.tar.gz and run TARDIS with:

    tar zxvf tardis_example.tar.gz
    cd tardis_example
    tardis tardis_example.yml output_spectrum.dat

Then plot the output_spectrum.dat with your favourite plotting program. Here’s an example how to do this with python. (The only thing you need to install is ipython and matplotlib - in addition to TARDIS’s requirements)

## Scripting TARDIS

    from tardis import config_reader, model, simulation

    tardis_config = config_reader.TARDISConfiguration.from_yaml('myconfig.yml')
    radial1d_mdl = model.Radial1DModel(tardis_config)
    simulation.run_radial1d(radial1d_mdl)